import React from "react";
import {render, fireEvent} from "@testing-library/react"
import { Provider } from "react-redux";

import Todo from "./Todo";
import todoReducer  from '../../features/todo/todosSlice'
import {configureStore} from "@reduxjs/toolkit";

const renderWithRedux = (
    ui: React.ReactElement,
    { store = configureStore({ reducer: { todos: todoReducer } }) } = {}
) => {
    return {
        ...render(<Provider store={store}>{ui}</Provider>),
        store,
    };
};
describe("Todo", () => {
    it("renders todo text and toggle button", () => {
        const todo = {
            id: 1,
            text: "Test todo",
            completed: false,
        };
        const { getByText, getByRole } = renderWithRedux(<Todo todo={todo} />);
        const todoText = getByText("Test todo");
        expect(todoText).toBeInTheDocument();
        const toggleButton = getByRole("checkbox");
        expect(toggleButton).toBeInTheDocument();
    });

    it("toggles todo when toggle button is clicked", () => {
        const todo = {
            id: 1,
            text: "Test todo",
            completed: false,
        };
        const { getByRole, store } = renderWithRedux(<Todo todo={todo} />);
        const toggleButton = getByRole("checkbox");
        fireEvent.click(toggleButton);
        expect(store.getState().todos.todos[0].completed).toBe(true);
    });

    it("deletes todo when delete button is clicked", () => {
        const todo = {
            id: 1,
            text: "Test todo",
            completed: false,
        };
        const { getByRole, store } = renderWithRedux(<Todo todo={todo} />);
        const deleteButton = getByRole("button");
        fireEvent.click(deleteButton);
        expect(store.getState().todos.todos).toHaveLength(0);
    });

})
