import { createSlice, PayloadAction } from "@reduxjs/toolkit";

export interface TodoItem {
    id: number;
    text: string;
    completed: boolean;
}

interface TodoState {
    todos: TodoItem[];
}

const initialState: TodoState = {
    todos: []
}

export const todosSlice = createSlice({
    name: 'todo',
    initialState,
    reducers: {
        addTodo: {
            reducer: (state, action: PayloadAction<TodoItem>) => {
                state.todos.push(action.payload);
            },
            prepare: (text: string) => ({
                payload: {
                    id: new Date().getTime(),
                    text,
                    completed: false,
                },
            }),
        },
        toggleTodo: (state, action: PayloadAction<number>) => {
            const todo = state.todos.find((todo) => todo.id === action.payload);
            if (todo) {
                todo.completed = !todo.completed;
            }
        },
        deleteTodo: (state, action: PayloadAction<number>) => {
            state.todos = state.todos.filter((todo) => todo.id !== action.payload);
        },
    },
})

export const { addTodo, toggleTodo, deleteTodo } = todosSlice.actions;
export default todosSlice.reducer;
